@@ -1,5 +1,5 @@
-__version__ = '0.5.1'
+__version__ = '0.5.3'
 
 from pychromatic.palette import Palette
-from pychromatic.plutils import Multiplot
+from pychromatic.plutils import Multiplot, BrokenAxes
 from pychromatic.decors import chromatify
